@@ -58,6 +58,12 @@
 
 #define ENABLE_DIRECT_RENDERING
 
+/* reordered_opaque appeared in libavcodec 51.68.0 */
+#define AVCODEC_HAS_REORDERED_OPAQUE
+#if LIBAVCODEC_VERSION_INT < 0x334400
+# undef AVCODEC_HAS_REORDERED_OPAQUE
+#endif
+
 typedef struct ff_video_decoder_s ff_video_decoder_t;
 
 typedef struct ff_video_class_s {
@@ -78,9 +84,12 @@ struct ff_video_decoder_s {
 
   xine_stream_t    *stream;
   int64_t           pts;
+#ifdef AVCODEC_HAS_REORDERED_OPAQUE
   uint64_t          pts_tag_mask;
   uint64_t          pts_tag;
   int               pts_tag_counter;
+  int               pts_tag_stable_counter;
+#endif /* AVCODEC_HAS_REORDERED_OPAQUE */
   int               video_step;
 
   uint8_t           decoder_ok:1;
@@ -1181,6 +1190,7 @@ static void ff_handle_mpeg12_buffer (ff_video_decoder_t *this, buf_element_t *bu
   }
 }
 
+#ifdef AVCODEC_HAS_REORDERED_OPAQUE
 static uint64_t ff_tag_pts(ff_video_decoder_t *this, uint64_t pts)
 {
   return pts | this->pts_tag;
@@ -1201,22 +1211,33 @@ static void ff_check_pts_tagging(ff_video_decoder_t *this, uint64_t pts)
 {
   if (this->pts_tag_mask == 0)
     return; /* pts tagging inactive */
-
-  if ((pts & this->pts_tag_mask) != this->pts_tag)
+  if ((pts & this->pts_tag_mask) != this->pts_tag) {
+    this->pts_tag_stable_counter = 0;
     return; /* pts still outdated */
+  }
+
+  /* the tag should be stable for 100 frames */
+  this->pts_tag_stable_counter++;
 
   if (this->pts_tag != 0) {
-    /* first pass: reset pts_tag */
-    this->pts_tag = 0;
+    if (this->pts_tag_stable_counter >= 100) {
+      /* first pass: reset pts_tag */
+      this->pts_tag = 0;
+      this->pts_tag_stable_counter = 0;
+    }
   } else if (pts == 0)
     return; /* cannot detect second pass */
   else {
-    /* second pass: reset pts_tag_mask and pts_tag_counter */
-    this->pts_tag_mask = 0;
-    this->pts_tag_counter = 0;
+    if (this->pts_tag_stable_counter >= 100) {
+      /* second pass: reset pts_tag_mask and pts_tag_counter */
+      this->pts_tag_mask = 0;
+      this->pts_tag_counter = 0;
+      this->pts_tag_stable_counter = 0;
+    }
   }
 }
 
+#endif /* AVCODEC_HAS_REORDERED_OPAQUE */
 static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
   uint8_t *chunk_buf = this->buf;
   AVRational avr00 = {0, 1};
@@ -1241,12 +1262,14 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
     this->size = 0;
   }
 
+#ifdef AVCODEC_HAS_REORDERED_OPAQUE
   if (this->size == 0) {
     /* take over pts when we are about to buffer a frame */
     this->av_frame->reordered_opaque = ff_tag_pts(this, this->pts);
     this->context->reordered_opaque = ff_tag_pts(this, this->pts);
     this->pts = 0;
   }
+#endif /* AVCODEC_HAS_REORDERED_OPAQUE */
 
   /* data accumulation */
   if (buf->size > 0) {
@@ -1301,8 +1324,10 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
                                     &got_picture, &chunk_buf[offset],
                                     this->size);
 
+#ifdef AVCODEC_HAS_REORDERED_OPAQUE
         /* reset consumed pts value */
         this->context->reordered_opaque = ff_tag_pts(this, 0);
+#endif /* AVCODEC_HAS_REORDERED_OPAQUE */
 
         lprintf("consumed size: %d, got_picture: %d\n", len, got_picture);
         if ((len <= 0) || (len > this->size)) {
@@ -1320,10 +1345,12 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
             memmove (this->buf, &chunk_buf[offset], this->size);
             chunk_buf = this->buf;
 
+#ifdef AVCODEC_HAS_REORDERED_OPAQUE
             /* take over pts for next access unit */
             this->av_frame->reordered_opaque = ff_tag_pts(this, this->pts);
             this->context->reordered_opaque = ff_tag_pts(this, this->pts);
             this->pts = 0;
+#endif /* AVCODEC_HAS_REORDERED_OPAQUE */
           }
         }
       }
@@ -1418,9 +1445,14 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
           ff_convert_frame(this, img);
         }
 
+#ifndef AVCODEC_HAS_REORDERED_OPAQUE
+        img->pts  = this->pts;
+        this->pts = 0;
+#else /* AVCODEC_HAS_REORDERED_OPAQUE */
         img->pts  = ff_untag_pts(this, this->av_frame->reordered_opaque);
         ff_check_pts_tagging(this, this->av_frame->reordered_opaque); /* only check for valid frames */
         this->av_frame->reordered_opaque = 0;
+#endif /* AVCODEC_HAS_REORDERED_OPAQUE */
 
         /* workaround for weird 120fps streams */
         if( video_step_to_use == 750 ) {
@@ -1460,8 +1492,13 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
                                                 this->output_format,
                                                 VO_BOTH_FIELDS|this->frame_flags);
       /* set PTS to allow early syncing */
+#ifndef AVCODEC_HAS_REORDERED_OPAQUE
+      img->pts       = this->pts;
+      this->pts      = 0;
+#else /* AVCODEC_HAS_REORDERED_OPAQUE */
       img->pts       = ff_untag_pts(this, this->av_frame->reordered_opaque);
       this->av_frame->reordered_opaque = 0;
+#endif /* AVCODEC_HAS_REORDERED_OPAQUE */
 
       img->duration  = video_step_to_use;
 
@@ -1547,9 +1584,12 @@ static void ff_reset (video_decoder_t *this_gen) {
   if (this->is_mpeg12)
     mpeg_parser_reset(this->mpeg_parser);
 
+#ifdef AVCODEC_HAS_REORDERED_OPAQUE
   this->pts_tag_mask = 0;
   this->pts_tag = 0;
   this->pts_tag_counter = 0;
+  this->pts_tag_stable_counter = 0;
+#endif /* AVCODEC_HAS_REORDERED_OPAQUE */
 }
 
 static void ff_discontinuity (video_decoder_t *this_gen) {
@@ -1558,6 +1598,7 @@ static void ff_discontinuity (video_decoder_t *this_gen) {
   lprintf ("ff_discontinuity\n");
   this->pts = 0;
 
+#ifdef AVCODEC_HAS_REORDERED_OPAQUE
   /*
    * there is currently no way to reset all the pts which are stored in the decoder.
    * therefore, we add a unique tag (generated from pts_tag_counter) to pts (see 
@@ -1571,9 +1612,11 @@ static void ff_discontinuity (video_decoder_t *this_gen) {
   this->pts_tag_counter++;
   this->pts_tag_mask = 0;
   this->pts_tag = 0;
+  this->pts_tag_stable_counter = 0;
   {
     /* pts values typically don't use the uppermost bits. therefore we put the tag there */
     int counter_mask = 1;
+    int counter = 2 * this->pts_tag_counter + 1; /* always set the uppermost bit in tag_mask */
     uint64_t tag_mask = 0x8000000000000000ull;
     while (this->pts_tag_counter >= counter_mask)
     {
@@ -1581,13 +1624,14 @@ static void ff_discontinuity (video_decoder_t *this_gen) {
        * mirror the counter into the uppermost bits. this allows us to enlarge mask as
        * necessary and while previous taggings can still be detected to be outdated.
        */
-      if (this->pts_tag_counter & counter_mask)
+      if (counter & counter_mask)
         this->pts_tag |= tag_mask;
       this->pts_tag_mask |= tag_mask;
       tag_mask >>= 1;
       counter_mask <<= 1;
     }
   }
+#endif /* AVCODEC_HAS_REORDERED_OPAQUE */
 }
 
 static void ff_dispose (video_decoder_t *this_gen) {
