@@ -253,6 +253,9 @@ static off_t net_plugin_read (input_plugin_t *this_gen,
 
   lprintf("reading %" PRIdMAX " bytes...\n", (intmax_t)len);
 
+  if (len < 0)
+    return -1;
+
   total=0;
   if (this->curpos < this->preview_size) {
     n = this->preview_size - this->curpos;
@@ -288,6 +291,11 @@ static buf_element_t *net_plugin_read_block (input_plugin_t *this_gen,
   buf_element_t        *buf = fifo->buffer_pool_alloc (fifo);
   off_t                 total_bytes;
 
+  if (todo < 0 || todo > buf->size) {
+    buf->free_buffer (buf);
+    return NULL;
+  }
+
   buf->content = buf->mem;
   buf->type = BUF_DEMUX_BLOCK;
   
@@ -331,7 +339,7 @@ static off_t net_plugin_seek (input_plugin_t *this_gen, off_t offset, int origin
   if ((origin == SEEK_CUR) && (offset >= 0)) {
 
     for (;((int)offset) - BUFSIZE > 0; offset -= BUFSIZE) {
-      if( !this_gen->read (this_gen, this->seek_buf, BUFSIZE) )
+      if( this_gen->read (this_gen, this->seek_buf, BUFSIZE) <= 0 )
         return this->curpos;
     }
 
@@ -353,7 +361,7 @@ static off_t net_plugin_seek (input_plugin_t *this_gen, off_t offset, int origin
       offset -= this->curpos;
 
       for (;((int)offset) - BUFSIZE > 0; offset -= BUFSIZE) {
-        if( !this_gen->read (this_gen, this->seek_buf, BUFSIZE) )
+        if( this_gen->read (this_gen, this->seek_buf, BUFSIZE) <= 0 )
           return this->curpos;
       }
 
@@ -480,7 +488,7 @@ static input_plugin_t *net_class_get_instance (input_class_t *cls_gen, xine_stre
     return NULL;
   }
 
-  this = xine_xmalloc(sizeof(net_input_plugin_t));
+  this = calloc(1, sizeof(net_input_plugin_t));
   this->mrl           = strdup(mrl);
   this->host_port     = strdup(filename);
   this->stream        = stream;
@@ -528,7 +536,7 @@ static void *init_class (xine_t *xine, void *data) {
 
   net_input_class_t  *this;
 
-  this         = (net_input_class_t *) xine_xmalloc(sizeof(net_input_class_t));
+  this         = calloc(1, sizeof(net_input_class_t));
   this->config = xine->config;
   this->xine   = xine;
 
