@@ -69,6 +69,7 @@ typedef struct deinterlace_parameters_s {
   int method;
   int enabled;
   int pulldown;
+  int pulldown_error_wait;
   int framerate_mode;
   int judder_correction;
   int use_progressive_frame_flag;
@@ -87,6 +88,8 @@ PARAM_ITEM( POST_PARAM_TYPE_BOOL, enabled, NULL, 0, 1, 0,
             "enable/disable" )
 PARAM_ITEM( POST_PARAM_TYPE_INT, pulldown, enum_pulldown, 0, 0, 0, 
             "pulldown algorithm" )
+PARAM_ITEM( POST_PARAM_TYPE_INT, pulldown_error_wait, NULL, 0, 0, 0, 
+            "number of frames of telecine pattern sync required before mode change" )
 PARAM_ITEM( POST_PARAM_TYPE_INT, framerate_mode, enum_framerate, 0, 0, 0, 
             "framerate output mode" )
 PARAM_ITEM( POST_PARAM_TYPE_BOOL, judder_correction, NULL, 0, 1, 0,
@@ -165,6 +168,7 @@ static int set_parameters (xine_post_t *this_gen, void *param_gen) {
   this->enabled = param->enabled;
 
   this->pulldown = param->pulldown;
+  this->tvtime->pulldown_error_wait = param->pulldown_error_wait;
   this->framerate_mode = param->framerate_mode;
   this->judder_correction = param->judder_correction;
   this->use_progressive_frame_flag = param->use_progressive_frame_flag;
@@ -185,6 +189,7 @@ static int get_parameters (xine_post_t *this_gen, void *param_gen) {
   param->method = this->cur_method;
   param->enabled = this->enabled;
   param->pulldown = this->pulldown;
+  param->pulldown_error_wait = this->tvtime->pulldown_error_wait;
   param->framerate_mode = this->framerate_mode;
   param->judder_correction = this->judder_correction;
   param->use_progressive_frame_flag = this->use_progressive_frame_flag;
@@ -212,6 +217,9 @@ static char * get_static_help (void) {
            "\n"
            "  Enabled: Enable/disable the plugin.\n"
            "\n"
+           "  Pulldown_error_wait: Ensures that the telecine pattern has been "
+           "locked for this many frames before changing to filmmode.\n"
+           "\n"
            "  Pulldown: Choose the 2-3 pulldown detection algorithm. 24 FPS films "
            "that have being converted to NTSC can be detected and intelligently "
            "reconstructed to their original (non-interlaced) frames.\n"
@@ -350,6 +358,7 @@ static void *deinterlace_init_plugin(xine_t *xine, void *data)
   class->init_param.method                     = 1; /* First (plugin) method available */
   class->init_param.enabled                    = 1;
   class->init_param.pulldown                   = 1; /* vektor */
+  class->init_param.pulldown_error_wait        = 60; /* about one second */
   class->init_param.framerate_mode             = 0; /* full */
   class->init_param.judder_correction          = 1; 
   class->init_param.use_progressive_frame_flag = 1;
